# pycolorbar

pycolorbar is available on [GitHub](https://github.com/ghiggi/pycolorbar) and was created by following people.

## Main Authors

- Gionata Ghiggi, GitHub: [@ghiggi](https://github.com/ghiggi), Email:  <gionata.ghiggi@epfl.ch>

## Contributors (in order of contributions)
